# Advent of Code Framework

https://adventofcode.com/

A framework for implementing Advent of Code solutions in Python.

## Quick Start

Pip install the project so you have access to the `aoc` command.

```bash
pip install aoc_framework
```

Create an empty directory you want to write your solutions in.

```bash
aoc init
```

Now, you are ready to start implementing your solutions!

```bash
aoc create 01 --year 2021
```

This will create python file, `2021/day01.py`, where you'll implement the solution.

After you've implemented the solution, you can run it with:

```bash
aoc run 01 --year 2021 -i input.txt
```
